# Version 0.1.4 (2018 Aug 7)

- More documentation updates. We now provide a sample training set and sample
  pre-trained networks on Zenodo, so it's much easier to work through the docs
  in a tutorial style if you'd like.
- Default `rho_Q_sign` to use the `generic` trainer in `neurosynchro
  init-nndir`. This scheme works a bit better with the sample training set.
- Fix the `binary` trainer!

# Version 0.1.3 (2018 Aug 4)

- Write a bunch of documentation
- Add a tool for doing test integrations to compare how well neurosynchro
  fares compared to fully-detailed calculations.

# Version 0.1.1 (2018 Jul 24)

- First packaged version; several micro releases to iterate on the ReadTheDocs
  infrastructure etc.
